Logic to represent an underlying file containing a Queens game.
Structs
- Input
Squares - This represents a solve state as part of an input file.
- Queens
File - This represents a parsed input file.
Logic to represent an underlying file containing a Queens game.